Prepare data analysis for binary and continuous outcomes with Supplied interval confidence identifies whether the dataframe is for Benefit or Risk analysis
prepare_br_supplied_ci.RdPrepare data analysis for binary and continuous outcomes with Supplied interval confidence identifies whether the dataframe is for Benefit or Risk analysis
Arguments
- df
(
data.frame) dataset eitherdf_benefit(selected benefit) ordf_risk(select risk).- colname
(
character) feature to fetch for the analysis eitherMean,Prop,Rate- metric_name
(
character) metric for which we must fetch the confidence interval if supplied (taken from the effect table) eitherDiff,RelRisk,OddsRatio,Diff_Rates- func
(
function) function used to calculate metrics (or BR points)